@@ -1,4 +1,5 @@
 from etl_bq_tools.utils.time_execution import get_time_function_execution
+from etl_bq_tools.utils import constants as cons
 
 
 def bq_set_project(project_id=None, logging=None):
@@ -8,14 +9,23 @@ def bq_set_project(project_id=None, logging=None):
     :return:
     """
     import os
+    from color_tools import cprint
 
     if not project_id:
         raise Exception('require var project_id: {project_id} ')
+
     try:
         os.system(f"gcloud config set project {project_id}")
-        logging.info(f"project update {project_id} ")
+
+        if logging:
+            logging.info(cons.txt_set_project_success.format(project_id))
+        else:
+            cprint(cons.txt_set_project_success.format(project_id))
     except:
-        logging.info(f"Project Not Found: {project_id} ")
+        if logging:
+            logging.info(cons.txt_set_project_errors.format(project_id))
+        else:
+            cprint(cons.txt_set_project_errors.format(project_id))
 
 
 @get_time_function_execution
@@ -28,6 +38,7 @@ def bq_execute_sql(sql=None, parameter=None, logging=None):
     """
 
     import os
+    from color_tools import cprint
 
     if not sql:
         raise Exception('require var sql: {file.sql} ')
@@ -49,6 +60,14 @@ def bq_execute_sql(sql=None, parameter=None, logging=None):
         else:
             sentence_bq = f"bq query --quiet  --use_legacy_sql=false --flagfile={sql} "
         os.system(sentence_bq)
-        logging.info(f"Successfully: {file_sql}")
+
+        if logging:
+            logging.info(cons.txt_execute_sql_success.format(file_sql))
+        else:
+            cprint(cons.txt_execute_sql_success.format(file_sql))
+
     except Exception as e:
-        logging.info(f"Error: {file_sql}")
+        if logging:
+            logging.info(cons.txt_execute_sql_errors.format(file_sql))
+        else:
+            cprint(cons.txt_execute_sql_errors.format(file_sql))
