@@ -1,4 +1,4 @@
-def reduce_memory(dataset, verbose=True):
+def get_reduce_memory(dataset, verbose=True):
     import numpy as np
     import pandas as pd
 
@@ -15,6 +15,7 @@ def reduce_memory(dataset, verbose=True):
     end_mem = ds_tmp.memory_usage().sum() / 1024 ** 2
     ds_tmp = ds_tmp.replace([np.inf, -np.inf], np.nan)
     if verbose:
-        print('Mem. usage decreased to {:5.2f} Mb ({:.1f} % reduction)'.format(end_mem, 100 * (start_mem - end_mem) / start_mem))
+        print(f'Memory usage after optimization is: {end_mem:.2f} MB')
+        print(f'Decreased by {100 * (start_mem - end_mem) / start_mem:.2f}%')
     del dataset
     return ds_tmp
